PROGRAM GW2EDIT;  { The Gateway Player Database Editor Utility }

  { Created program using FO2EDIT code on Dec. 10th, 2009. }
  { ====================================================== }

USES CRT, GoldWin, GoldFast, GoldRead, GoldMisc, ChasWare;

     {$I GATEVARS.INC}         {January 2011 Beta}
	  { =================================================================================== }

CONST Version: STRING = 'v0.34 Beta';
        {03/10/10: use v0.32 beta.   12/27/10:  use v0.34 beta}

      Compile_Date: STRING = 'December 27, 2010.';
      { ------------------------------------------------ }

      CfgName: STRING = 'GW2EDIT.CFG';

      GatePlayer_FN: STRING = 'GATEPLAY.DAT';

      RealName    = '1';   LordName   = '2';   PlayNum   = '3';
      IGMVisits   = '4';   Adopted    = '5';

      { FRescue = '6';  }  {01/20/10 entry: not enabled yet}

      { ------------------------------------------------------- }
      { Editor will NOT to access fields in the IGM's VARIABLES }
      { and VISIT arrays used in the Player Database structure. }

      { Reason: Variables contains 1 array with 60 elements which }
      {   holds a 2nd array with 5 elements.  Visit contains an   }
      {   array containing 60 elements.  Editor also will NOT   }
      {   cover HITMAX, STRENGTH, DEFENSE, CHARM, FOREST, GEMS, }
      {   GOLD, or WISDOM.  None of those stats can be updated  }
      {   by the RHP Library when matching RHP codes are    }
      {   manipulated by IGM scripts run by the IGM.        }
      { ------------------------------------------------------- }

      { Q - Quit/Save Changes.   S - Search for Player. }
      { * - New Day for Player.  X - Delete Player }
      { ------------------------------------------------------- }

      Max_IGMVisits: BYTE = 20;
{ ============================================================ }

VAR TSearch: GATEWAY_PLAYER;   { for player searches }

    TGEdit: GATEWAY_PLAYER;

    Editor_Path: STRING;      { File Vars for GATEPLAY.DAT access }

    Editor_File:  FILE OF GATEWAY_PLAYER;

    IGMDir: STRING;

    RecordNum   : BYTE;

    Debug_Mode: BOOLEAN;
          {01/20/10: Renamed DebugVar to Debug_Mode.}

      { TempNum, Used, Found: Accessed from GATEVARS.INC.   Used }
      { in record Seek process.  }
    { ================================================================================== }

PROCEDURE READ_CONFIG;      {Created 12/10/09: Verified 4:14 am}
  VAR Config_File: TEXT;

  PROCEDURE MakeConfig;          {coded 12/10/09: verified 4:14 am}
    VAR IGMLoc: STRING;
  BEGIN
    IGMLoc:= PromptStr(0,0,60,'Enter path to The Gateway IGM',' Installation ','',FALSE);
    IGMLoc:= S2U(IGMLoc);

    Addtext(AddBack(IGMLoc),CfgName,TRUE);
  END;   { ------------------------------------------------------------- }

BEGIN
  IF NOT Exist(CfgName) THEN MakeConfig;      {coded 12/10/09: verified 4:14 am}

  ASSIGN(Config_File,CfgName);
  RESET(Config_File);
  Readln(Config_File,IGMDir);
  CLOSE(Config_File);

  IGMDir:= S2U(IGMDir);

  { GW2EDIT: not tested via compiler yet }
END;       { Read_Config ------------------------------------------------- }


PROCEDURE READ_WARRIORS_FILE;    { Reads the IGM's GATEPLAY.DAT file. }
BEGIN
  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  FileMode:= $12;

  ASSIGN(Editor_File,Editor_Path);
  RESET(Editor_File);

  SEEK(Editor_File,RecordNum);
  READ(Editor_File,TGEdit);

  CLOSE(Editor_File);
END;     { ---------------------------------------------------- }


PROCEDURE WRITE_WARRIORS_FILE;      { Writes IGM's GATEPLAY.DAT file }
BEGIN
  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  FileMode:= $12;

  ASSIGN(Editor_File,Editor_Path);
  RESET(Editor_File);

  SEEK(Editor_File,RecordNum);
  WRITE(Editor_File,TGEdit);

  CLOSE(Editor_File);
END;     { WRITE_WARRIORS_FILE   ------------------------------ }


PROCEDURE SEARCH_PLAYER(Num:INTEGER);
                   { Does search on player record number }
BEGIN
  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  FileMode:= $12;

  ASSIGN(Editor_File,Editor_Path);
  RESET(Editor_File);

  SEEK(Editor_File,Num);
  READ(Editor_File,TSearch);

  CLOSE(Editor_File);
END;     { SEARCH_PLAYER  --------------------------------------------- }

    
FUNCTION Get(b:CHAR): STRING;
BEGIN
  CASE UpCase(b) OF
     RealName : Get:='`!'+TGEdit.RealName;

     LordName : Get:='`$'+TGEdit.LordName;

     PlayNum  : Get:='`@'+N2S(TGEdit.PlayNum);
                  { Contains player's LORD player #. }

     IGMVisits: IF TGEdit.IGM_Visits = 0
                  THEN  Get:= '`#None'
                  ELSE  Get:= '`$'+N2S(TGEdit.IGM_Visits);

     Adopted  : IF TGEdit.Adoptions = 0
                  THEN  Get:= '`#None'
                  ELSE  Get:= '`$'+COMMA(TGEdit.Adoptions);

     (*  {Not enabled yet.  Entry added 01/20/10 5:45 pm}
     FRescue  : IF TGEdit.Fairy_Rescue
                  THEN Get:= '`@Yes! '
                  ELSE Get:= '`0Nope!';
            { Used for IGM's Fairy_Rescue boolean VAR}  *)

  END;  {CASE}

  CursorOff;   {10/15/07.  needed to fix bug found by Dennis Collins}
               { in 2006 when he checked on KLBEDIT. }

    { When program's user would change a setting in a dialog box, when }
    { they returned to the main screen, the cursor would be back on the }
    { screen, so this keeps the cursor deactivated while the editor runs. }
END;     { GET Func. ----------------------------------------------------- }


{ 1 }PROCEDURE DO_REAL_NAME;          {coded 12/10/09: verified 4:14 am}
BEGIN
  TGEdit.RealName:=
    PromptStr(0,0,50,'Enter REAL name for player',' Player Real Name Change ',TGEdit.RealName,FALSE);

  WRITE_WARRIORS_FILE;
  CWriteXy(22,4,Replicate(50,' '));  { Write data on position 25, Line #4. }
  CWriteXy(22,4,Get(RealName));
END;


{ 2 }PROCEDURE DO_LORD_NAME;            {coded 12/10/09: verified 4:14 am}
BEGIN
  TGEdit.LordName:=
    PromptStr(0,0,20,'Enter LORD Name for player',' Player Lord Name Change ',TGEdit.LordName,FALSE);

  WRITE_WARRIORS_FILE;
  CwriteXY(22,5,Replicate(20,' '));
  CwriteXY(22,5,Get(LordName));
END;


  { In normal usage, don't allow users to change LORD Player Numbers. }
{ 3 }PROCEDURE DO_PLAYER_NUMBER;       {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
BEGIN
  TGEdit.PlayNum:=
    PromptNum(0,0,'Enter player''s LORD Player # (0-160)?',' LORD Player Number Change ',TGEdit.PlayNum,0,160,TRUE);

  WRITE_WARRIORS_FILE;
  CWriteXy(58,5,Replicate(5,' '));    { Allow room for 3 digits, and 2 blank spaces. 07/13/05}
  CWriteXy(58,5,Get(PlayNum));
END;


{ 4 }PROCEDURE DO_IGM_VISITS;        {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
BEGIN
  TGEdit.IGM_Visits:=
    PromptNum(0,0,'Enter IGM Visits Today (0-20)?',' IGM Visits Today Change',TGEdit.IGM_Visits,0,Max_IGMVisits,TRUE);

  WRITE_WARRIORS_FILE;
  CwriteXY(26,6,Replicate(5,' '));     {Verified position 4:20 am 12/10/09}
  CwriteXY(26,6,Get(IGMVisits));
END;   {IGM's Max IGMVisits/Day Limit is 20, as of mid-Nov 2009.}


{ 5 }PROCEDURE DO_ADOPTIONS;                 {coded 12/10/09: verified 4:14 am}
BEGIN
  TGEdit.Adoptions:=
    PromptNum(0,0,'Enter # of Adoptions (-50 to 5,000)?',' Adoptions Change',TGEdit.Adoptions,-50,5000,TRUE);

  WRITE_WARRIORS_FILE;
  CWriteXY(61,6,Replicate(7,' '));   {Verified position 4:20 am 12/10/09}
  CWriteXY(61,6,Get(Adopted));
END;         {01/21/10: Changed from pos 64 to pos 61.}


(*  {Added 01/20/10: not enabled yet. 5:46 pm}

{ 6 }PROCEDURE DO_FAIRY_RESCUE;    {Created 01/10/20: VERIFIED 01/21/10 2:25 am}             {VERIFIED 12/04/07}
BEGIN
  IF TGEdit.Fairy_Rescue = TRUE THEN TGEdit.Fairy_Rescue:= FALSE
    ELSE IF TGEdit.Fairy_Rescue = FALSE THEN TGEdit.Fairy_Rescue:= TRUE;
           {uses revised LC2EDIT code 01/20/10}

  WRITE_WARRIORS_FILE;
  CWriteXY(26,7,Replicate(6,' '));
  CWriteXY(26,7,Get(FRescue));
END;             *)


{ note: To use Y, N responses via keyboard, one has to use the }
{ ALT key. Or simply use the mouse to click on the option wanted. }

{ * }PROCEDURE DO_NEW_DAY;     {VERIFIED 12/10/09 4:10 am}
BEGIN
  CWGotoXY(5,19);    {Write data on Line #19.}
  CWriteLn('  `0Running `!"Reset Player''s Stats" `0process. 3-second delay.');

  DELAY(3000);

  IF (TGEdit.PlayNum > 160) THEN  {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
    BEGIN
      TGEdit.PlayNum:= 160;
      PromptOK('Advisory:',' Resetting LORD Player # field to 160.');
    END;

  { --------------------------------------------------- }
        {BYTE field; Values can't be negative}
  IF TGEdit.IGM_Visits > 0 THEN       {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
    BEGIN
      TGEdit.IGM_Visits:= 0;
      PromptOK('Advisory:',' Resetting the IGM Visits Today field to Zero.');
    END;

  { --------------------------------------------------- }
  { Note: ADOPTIONS is INTEGER type, so it can be negative. }

  IF TGEdit.Adoptions < 0 THEN   {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
    BEGIN
      TGEdit.Adoptions:= 0;
      PromptOK('Advisory:',' Reset negative Adoptions field to Zero.');
    END;

  IF TGEdit.Adoptions > 0 THEN   {Created 12/10/09: VERIFIED 12/10/09 4:10 am}
    BEGIN
      TGEdit.Adoptions:= 0;
      PromptOK('Advisory:',' Resetting the Adoptions field to Zero.');
    END;

  { TGEdit.Fairy_Rescue:= FALSE;  }
      {Added 01/20/10: not enabled yet}
      { used only when IGM executes RHP Scripts. }

END;     { DO_NEW_DAY  ================================== }


FUNCTION  MAX_PLAYERS: WORD; { Gets the number of customer records }
BEGIN
  MAX_PLAYERS:= 1;

  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  IF NOT Exist(Editor_Path) THEN Exit;

  FileMode:= $12;

  ASSIGN(Editor_File,Editor_Path);
  RESET(Editor_File);

  MAX_PLAYERS:= FileSize(Editor_File);

  CLOSE(Editor_File);
END;     { MAX_PLAYERS  --------------------------------------------- }


FUNCTION GetRecordNum: STRING;
BEGIN
  GetRecordNum:='`$'+N2S(RecordNum + 1)+' `%of `@'+N2S(MAX_PLAYERS);
    { First record # displayed will be 1, not 0. }
END;     { GetRecordNum ---------------------------------------------- }


       {01/20/10: Changed ShowMenu to SHOW_MENU.}
PROCEDURE SHOW_MENU;
BEGIN
  ClrScr;

  CWritelnC('`%    ** `$The Gateway''s `0Player Database Editor `!'+Version+' `%**');  {Line 1}
  CWritelnC('`@    GATEPLAY.DAT `%Record Number:  `$'+GetRecordNum);              {Line 2}
  CWriteLn(' ');

  { CwGotoXY, CWriteXY notes: X is position #, Y is line #. }

  CWGotoXY(3,4);   { Line 4 }
  CWriteLN('`#(`%1`#) `!Real Name    `%: '+Get(RealName));

  { -------------------------------------------- }
  CWGotoXY(3,5);                {Line 5}
	 CWrite('`#(`%2`#) `!LORD Name    `%: '+Get(LordName));

  CWGotoXY(45,5);
  CWriteLN('`#(`%3`#) `!Player #`%: '+Get(PlayNum));
  { -------------------------------------------- }

  CWGotoXY(3,6);        {Line 6, column 1. temp coding}
   CWrite('`#(`%4`#) `!IGM Visits Today `%: '+Get(IGMVisits));

  CWGotoXY(42,6);   {01/21/10: Changed from pos 45 to pos 42.}
  CWriteLN('`#(`%5`#) `!Kids Adopted `%: '+Get(Adopted));
  { -------------------------------------------- }

  (*  {Added 01/20/10 5:51 pm: not enabled yet}
  CWGotoXY(3,7);          {01/20/10}
  CWriteLN('`#(`%6`#) `!Fairy Rescue? `%: '+Get(FRescue));  {01/20/10}
                 *)

  CWGotoXY(3,8);          {01/20/10}
  CWriteLn(' ');  {Blank Line #1. Line #8}

  CWGotoXY(3,9);          {01/20/10}
  CWriteLn(' ');  {BLank Line #2. Line #9}

  { --------------------------------------------------------------- }
  CWGotoXY(3,10);        {use Line #10}
    CWrite('`2(`0S`2) `%Search for Player');
       {01/20/10: Changed "Search by Name" to "Search for Player".}

  CWGotoXY(40,10);
	 CWrite('`2(`0]`2) `%Advance One Record');
  { -------------------------------------------- }

  CWGotoXY(3,11);        {use Line #11}
	 CWrite('`2(`0[`2) `%Back Up One Record');

  CWGotoXY(40,11);
  CWriteln('`2(`0*`2) `%Reset Player Stats');
  { -------------------------------------------- }

  CWGotoXY(3,12);      {Added 01/20/10}
  CWriteLn('`2(`0X`2) `%Delete Current Player');   {Added 01/20/10}

  CWriteln(' ');  {Blank Line, Line #13}  {edited 01/20/10}

  CWGotoXY(3,14);   {Edited 01/20/10}
  Cwrite('`$    Input key to change, or `%Q `$to Quit and Save.');

  IF Debug_Mode THEN    {Added 01/20/10: VERIFIED 01/21/10 2:25 am}
    CWrite('  `@[Debug Mode] ');

END;     { SHOW_MENU  ----------------------------------------- }


{ S }PROCEDURE DO_PLAYER_SEARCH;
VAR Counter, YN : BYTE;
    Temp, OTemp : STRING;

BEGIN
  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  IF NOT Exist(Editor_Path) THEN Exit;
     { if no GATEPLAY.DAT then we can't search and }
     { couldn't have made it here to begin with. }

  Counter:= 0;
  Temp:= PromptStr(0,0,50,' Enter full or partial name: ',' Player Search ','',FALSE);
  OTemp:= Temp;
  Temp:= S2U(Temp);  { upcase the whole string }

  REPEAT
    SEARCH_PLAYER(Counter);

    { This next evaluation is checking to see if TEMP exists anywhere in  }
    {  either field of record.  If YES, then execute the next section,    }
    {  otherwise increment counter and move on.  Note: Using FUNCTION NoColor  }
    {  to strip Lord color codes for string eval and display. }

	 IF (POS(Temp,S2U(TSearch.LordName))>0) OR (POS(Temp,NoColor(S2U(TSearch.RealName)))>0) THEN
     BEGIN
		 YN:= PromptYesNo('','Are you looking for:|'+TSearch.LordName+' known as '+NoColor(TSearch.RealName)+'?');

       IF YN=1 THEN {1 means YES answer}
         BEGIN
            RecordNum:= Counter; { LORD Player # to display matches the counter }

            READ_WARRIORS_FILE;
            SHOW_MENU;
            Exit; { bail out of loop since we got who we want }
          END;
     END;

    INC(Counter);
  UNTIL Counter=MAX_PLAYERS; { End of repeat loop, repeats until we get
										to last player record. }

  { if we make it to here, then there were no matches. }

  PromptOK(' Search Error! ','No match found for '+OTemp+'!');  {02/11/04}
END;   { DO_PLAYER_SEARCH ====================================== }


  {Disabled DO_NEWDAY_TESTING 12/30/2009 after event usage was verified.}
  {01/20/10: Deleted disabled DO_NEWDAY_TESTING process.}


{ Added 01/20/10 using modified OT20EDIT.PAS code: }

{ X }PROCEDURE DO_PLAYER_DELETION;   {Created 01/20/10: VERIFIED 01/21/10 2:25 am}
  VAR YN: BYTE;
BEGIN
  { I hate having to bust up lines due to "line too long" error }
  { messages! The next 3 lines are all one line of code. Chas.}

  YN:= PromptYesNo
   (' Warning Will Robinson! Player Deletion! ','Are you sure you want to delete the player :|'+TGEdit.LordName+' known'
     +' as '+NoColor(TGEdit.RealName)+'?');

  IF YN = 1 THEN {1 means YES answer}
    BEGIN
      { Program does not access, display or modify values stored }
      { in the VARIABLES array or in the VISIT array. }

      TGEdit.RealName:= 'X';
      TGEdit.LordName:= '* DELETED *';

      TGEdit.PlayNum:= 160;

        { Note: PlayNum 160 should not be in use by any valid players.}

      TGEdit.IGM_Visits:= 0;

      TGEdit.HitMax:= 0;
      TGEdit.Strength:= 0;
      TGEdit.Defense:= 0;
      TGEdit.Charm:= 0;
      TGEdit.Forest:= 0;
      TGEdit.Gems:= 0;

      TGEdit.Adoptions:= 0;
      TGEdit.Gold:= 0;
      TGEdit.Wisdom:= 0;

      {  TGEdit.Fairy_Rescue:= FALSE;  }
         {01/20/10 entry: not enabled yet}
      { ========================================== }

      WRITE_WARRIORS_FILE;

      PromptOK(' Record Deletion: ','Actual record deletion will be handled by the IGM the |'
                 +'next day, when it runs the New Day maintenance process. ');

      SHOW_MENU;
    END;
END;       {  DO_PLAYER_DELETION ==============================  }


PROCEDURE RUN_EDITOR;       {VERIFIED 12/10/09 4:10 am}
  VAR Code: CHAR;
BEGIN
  SHOW_MENU;

  REPEAT
    Code:= AInput('123456QSX][*');
       {01/20/10: Deleted # key.  Added 6, X keys}

    CASE Code OF
      '1' : DO_REAL_NAME;       {Created 12/10/09: verified 4:12 am}

      '2' : DO_LORD_NAME;       {Created 12/10/09:  verified 4:12 am}

      '3' : BEGIN               {Created 12/10/09:  verified 4:12 am}
              CWGotoXY(1,9);       {Show text on Line 9}

              CWriteLn('                                                                      ');  {09/13/08. needed here}
                {Writes blank line to screen. Line #9. 01/20/10}

              CWriteLn('  `0The `$LORD Player Number `0field is display-only.  I don''t see ');
              CWriteLn('  `0a valid reason to allow it to be edited.  3-second delay. ');
              DELAY(3000);

              IF Debug_Mode THEN   {Created 12/10/09: VERIFIED 01/21/10 2:25 am}
                BEGIN
                  BLANK(1);
                  CWriteLn('  `0Usage of `!/DEBUG `0parameter was detected, so user is ');
                  CWriteLn('  `0allowed to modify the Player Number field.  Do so with ');
                  CWriteLn('  `@CAUTION `0because it is a `@VERY `0important database field.');
                  DELAY(3000);

                  DO_PLAYER_NUMBER;
                END;

              SHOW_MENU;
            END;

      '4' : DO_IGM_VISITS;       {Created 12/10/09: VERIFIED 12/10/09 4:10 am}

      '5' : DO_ADOPTIONS;        {Created 12/10/09: VERIFIED 12/10/09 4:10 am}

      (*  {Added 01/20/10 5:57 pm: not enabled yet}
      '6' : DO_FAIRY_RESCUE;     {Coded 01/20/10}     *)


      { IGM structure contains other IGM stats, but I see NO  }
      { point in working with them since I can't figure out a }
      { way for the RHP library to update their values in the }
      { IGM scripts without it updating the mathing LORD stat }
      { two separate times. Dec. 10, 2009 notes.              }
      { ===================================================== }

      { ------------------------------------------------------ }
      { Q - reserved for QUIT/SAVE Changes command processing. }
      { ------------------------------------------------------ }

      'S' : DO_PLAYER_SEARCH;    {Created 12/10/09: VERIFIED 01/21/10 2:25 am}

      { ------------------------ Added 01/20/10 --------------- }
      'X' : BEGIN               {Created 01/20/10: VERIFIED 01/21/10 2:25 am}
              CWGotoXY(1,9);   {Start on Line 9}

              CWriteLn('                                                                      ');  {09/13/08. needed here}
                  {Writes blank line to screen. Line #9. 01/20/10}

              CWriteLn('  `0The `@Delete Player Record `0option is only usable when `$GW2EDIT ');
              CWriteLn('  `0is executed in `%Debug Mode, `0using the `!/Debug `0parameter. ');
              CWriteLn('  `!This option should only be used with `@EXTREME `!caution!!         ');
                      {01/20/10: rewrote wording of third line}

              CWriteLn('                                                                      ');  {09/13/08. needed here}
                  {Writes blank line to screen. Line #13. 01/21/10}

              DELAY(4000);     {wording layout verified}

              IF Debug_Mode THEN   {Created 01/20/10: VERIFIED 01/21/10 2:25 am}
                BEGIN
                  CWriteLn('  `0Usage of `!/DEBUG `0parameter was detected, so user is allowed     ');
                        {01/21/10: added blank spaces to cover up [Debug Mode] on-screen.}

                  CWriteLn('  `0to `#Delete this Record.  `0Do this only if absolutely necessary! ');
                  DELAY(3000);

                  DO_PLAYER_DELETION;
                END;

              SHOW_MENU;
            END;
      { ------------------------------------------------------ }

      {01/20/10: Deleted disabled DO_NEWDAY_TESTING statement}

      ']' : BEGIN
              INC(RecordNum);
              IF RecordNum > (MAX_PLAYERS - 1) THEN RecordNum:= 0;  {05/07/04 edit}

              READ_WARRIORS_FILE;
              SHOW_MENU;
            END;

      '[' : BEGIN                      {Created 12/10/09: VERIFIED 01/21/10 2:25 am}
              IF RecordNum=0
                THEN RecordNum:= (MAX_PLAYERS - 1)
                ELSE Dec(RecordNum);

              READ_WARRIORS_FILE;
              SHOW_MENU;
            END;

      '*' : BEGIN               {VERIFIED 12/10/09 4:10 am}
              DO_NEW_DAY;

              SHOW_MENU;

              WRITE_WARRIORS_FILE;
            END;

    END;       {CASE Code - ending}
  UNTIL Code = 'Q';
END;       { RUN_EDITOR ---------------------------------------------------------- }


PROCEDURE EXIT_SCREEN;          {VERIFIED 12/10/09 4:10 am 12/10/09}
BEGIN
  { the | character will cause a linefeed, I forget what max chars }
  { are.  Anyhow, say whatever you want here or remove it totally }

  PromptOK(' The Gateway''s Player Database Editor Credits: ',
      'GW2EDIT.EXE '+Version+'.  Copyright 2009-2011 by Donald Tidmore. ||'

      +'** Dedicated to my beta tester Christopher Gosse. ** ||'  {12/10/09}

      +'** Compile Date:  '+Compile_Date+'  January 2011 Beta. ||'

      +'Database Path: '+Editor_Path);

          {Compile_Date ends with a period.}
END; { EXIT_SCREEN ============================================ }


BEGIN    { Main GW2EDIT.pas BEGIN/END structure }
  ClrScr;

  CursorOff;                  {Gold Tool-Kit process}
  UseLordColors:= TRUE;

  Debug_Mode:= FALSE;   {07/22/07 Code}

  IF S2U(ParamStr(1)) = '/DEBUG'  {07/22/07 Code}
    THEN Debug_Mode:= True;

  ReadVars.ReadHelp:= NIL;  { removes the HELP button in the prompts. }   {Gold Tool-Kit process}

  WinNoClose:= TRUE;
      { removes the prompt window close button in upper left. }
      {Gold toolkit process}

  RecordNum:= 0;

  IF Exist('GATEPLAY.DAX') THEN DeleteFile('GATEPLAY.DAX');

  READ_CONFIG;  {process existing GW2EDIT.CFG file.}

  Editor_Path:= S2U(IGMDIR+GatePlayer_FN);

  IF Exist(Editor_Path) THEN READ_WARRIORS_FILE
  ELSE
    BEGIN
      CWriteLn(' ');
      CWriteLn('  `@ERROR:  `0GW2EDIT `!could not locate `@The Gateway''s ');
      CWriteLn('  `#GATEPLAY.DAT `!file, which is `%REQUIRED `!for you to edit ');
      CWriteLn('  `!the IGM''s database records.');

      CWriteLn(' ');
      CWriteLn('  `0GW2EDIT `!looked for this file, which was not found: ');
      CWriteLn('    `$'+Editor_Path);

      CWriteLn(' ');   {12/18/09}
      CWriteLn('  `#Problem Solving Note: `%Make sure the `!GW2EDIT.CFG `%file contains ');
                      {12/18/09: verified 12/30/09}
      CWriteLn('  `%the correct path to where the IGM''s data files are located.');      {12/18/09}

      CWriteLn(' ');
      CWriteLn('  `!Terminating `0GW2EDIT `!after 3 seconds delay.  ');

      CWriteLn('  `0This program requires `#The Gateway `%v1.31+ Beta.');

      DELAY(3000);
      HALT;
    END;
  { =========================================================== }

  RUN_EDITOR;

  EXIT_SCREEN;

  ResetStartUpMode;     {Gold Toolkit process}
END. { GW2EDIT.pas }

{ Finished program creation on 12/10/2009 04:03 am. }
{ First version used is 0.10 Beta. }

{ first successful compilation. 4:12 am 12/10/2009. }
{ Verified program works correctly. v0.20 Beta.  4:23 am. }

        {12/10/09: v0.10 beta created;  v0.20 beta after testing done}
         {12/18/09: minor edits. v0.25 used}

